@@ -18,24 +18,32 @@
 #include "obexpushd.h"
 #include "net.h"
 #include "core.h"
+#include "compiler.h"
 
-void obex_action_disconnect (file_data_t* data, obex_object_t* obj, int event)
+#include <unistd.h>
+
+static void disconnect_reqhint(file_data_t *data, obex_object_t *obj)
 {
-	switch (event) {
-	case OBEX_EV_REQHINT: /* A new request is coming in */
-		obex_send_response(data, obj, OBEX_RSP_CONTINUE);
-		break;
+	/* A new request is coming in */
+	obex_send_response(data, obj, 0);
+}
 
-	case OBEX_EV_REQ:
-		data->target = OBEX_TARGET_NONE;
-		if (data->transfer.path) {
-			free(data->transfer.path);
-			data->transfer.path = NULL;
-		}
-		break;
-
-	case OBEX_EV_REQDONE:
-		net_disconnect(data->net_data);
-		break;
+static void disconnect_request(file_data_t *data, obex_object_t __unused *obj)
+{
+	if (data->transfer.path) {
+		free(data->transfer.path);
+		data->transfer.path = NULL;
 	}
 }
+
+static void disconnect_done(file_data_t *data, obex_object_t __unused *obj)
+{
+	sleep(1);
+	net_disconnect(data->net_data);
+}
+
+const struct obex_target_event_ops obex_action_disconnect = {
+	.request_hint = disconnect_reqhint,
+	.request = disconnect_request,
+	.request_done = disconnect_done,
+};
