@@ -7,12 +7,14 @@
 #define O_CLOEXEC 0
 #endif
 
+#define set_closexec_flag(fd) fcntl(fd, F_SETFD, FD_CLOEXEC)
+
 static inline int open_closexec(const char *pathname, int flags, mode_t mode) {
 	int err = open(pathname, (flags | O_CLOEXEC), mode);
 
 #if ! O_CLOEXEC
 	if (err != -1)
-		(void)fcntl(err, F_SETFD, FD_CLOEXEC);
+		(void)set_closexec_flag(err);
 #endif
 
 	return err;
@@ -24,8 +26,8 @@ static inline int pipe_closexec(int pipefd[2]) {
 #else
 	int err = pipe(pipefd);
 	if (err != -1) {
-		(void)fcntrl(pipefd[0], F_SETFD, FD_CLOEXEC);
-		(void)fcntrl(pipefd[1], F_SETFD, FD_CLOEXEC);
+		(void)set_closexec_flag(pipefd[0]);
+		(void)set_closexec_flag(pipefd[1]);
 	}
 	return err;
 #endif
