@@ -11,13 +11,14 @@
 #include "io.h"
 
 enum obex_target {
-  OBEX_TARGET_NONE = 0, /* NOT CONNECTED */
-  OBEX_TARGET_OPP, /* ObjectPush */
+  OBEX_TARGET_OPP = 0, /* ObjectPush */
   OBEX_TARGET_FTP, /* File Browsing Service */
 
   OBEX_TARGET_MAX_NB
 };
 
+struct obex_target_ops;
+
 /* private data for a client connection */
 typedef struct {
 	unsigned int id;
@@ -26,6 +27,7 @@ typedef struct {
 
 	uint8_t buffer[1000];
 	enum obex_target target;
+	const struct obex_target_ops *target_ops;
 	int command;
 
 	struct net_data* net_data;
@@ -35,13 +37,29 @@ typedef struct {
 	struct io_transfer_data transfer;
 } file_data_t;
 
+struct obex_target_event_ops {
+	void (*request_hint)(file_data_t*, obex_object_t*);
+	void (*request_check)(file_data_t*, obex_object_t*);
+	void (*request)(file_data_t*, obex_object_t*);
+	void (*request_done)(file_data_t*, obex_object_t*);
+
+	void (*stream_in)(file_data_t*, obex_object_t*);
+	void (*stream_out)(file_data_t*, obex_object_t*);
+
+	void (*error)(file_data_t*, obex_object_t*, int);
+};
+
+struct obex_target_ops {
+	const struct obex_target_event_ops *post_connect;
+	const struct obex_target_event_ops *put;
+	const struct obex_target_event_ops *get;
+	const struct obex_target_event_ops *setpath;
+	const struct obex_target_event_ops *pre_disconnect;
+};
+
 void obex_send_response (file_data_t* data, obex_object_t* obj, uint8_t respCode);
 
 extern int debug;
 void dbg_printf (file_data_t *data, const char *format, ...) __attribute__((format(printf,2,3)));
 
-int check_name (uint8_t *name);
-int check_type (uint8_t *type);
-int check_wrap_utf16 (uint16_t *name, int (*func)(uint8_t*));
-
 #endif
