@@ -33,6 +33,11 @@
 #include <windows.h>
 #include <shlwapi.h>
 #define strdup(s) StrDup(s)
+
+#else
+#ifdef USE_XATTR
+#include <attr/xattr.h>
+#endif
 #endif
 
 enum ft {
@@ -82,11 +87,33 @@ enum ft filetype (mode_t m)
 		return FT_OTHER;
 }
 
+#ifdef USE_XATTR
+static int get_mime_type (
+	const char *filename,
+	char *type,
+	size_t size
+)
+{
+	ssize_t status = lgetxattr(filename, "user.mime_type", type, size);
+
+	if (status >= 0)
+		return 0;
+
+	if (strlen(type) != (size_t)status)
+		errno = EINVAL;
+
+	return -errno;
+}
+#endif
+
 static
 void print_filename (FILE* fd, const char* filename, mode_t st_parent, int flags)
 {
 	struct stat s;
-	const char* name;
+	const char *name;
+#ifdef USE_XATTR
+	char type[256];
+#endif
 	char create_time[17];
 	char mod_time[17];
 	char acc_time[17];
@@ -121,6 +148,12 @@ void print_filename (FILE* fd, const char* filename, mode_t st_parent, int flags
 
 	fprintf(fd," name=\"%s\" size=\"%zd\"",name,s.st_size);
 
+#ifdef USE_XATTR
+	if (!get_mime_type(name,type,sizeof(type))) {
+		fprintf(fd," type=\"%s\"",type);
+	}
+#endif
+
 	if (flags & OFL_FLAG_TIMES) {
 		if (strftime(create_time,15,"%Y%m%dT%H%M%SZ",gmtime(&s.st_ctime)))
 			fprintf(fd," created=\"%s\"",create_time);
@@ -167,6 +200,7 @@ void print_dir (FILE* fd, const char* dir, int flags)
 	mode_t mode;
 	struct dirent* entry = NULL;
 	char* seperator;
+	char *tmp;
   
 	if (dir == NULL)
 		return;
@@ -182,7 +216,11 @@ void print_dir (FILE* fd, const char* dir, int flags)
 		if (strcmp(entry->d_name,".") == 0 ||
 		    strcmp(entry->d_name,"..") == 0)
 			continue;
-		filename = realloc(filename,flen+strlen(entry->d_name));
+		tmp = realloc(filename,flen+strlen(entry->d_name));
+		if (!tmp)
+			break;
+		else
+			filename = tmp;
 		sprintf(filename,"%s%s%s",dir,seperator,entry->d_name);
 		print_filename(fd,filename,mode,flags);
 	}
@@ -224,7 +262,7 @@ int obex_folder_listing (FILE* fd, char* name, int flags)
 	mode_t m = 0;
 	int err = 0;
 	size_t namelen = (name? strlen(name): 0);
-	char* parent = get_parent_folder_name(name);
+	char* parent;
 
 #if _WIN32
 	/* backslash dir seperator must be converted to unix format*/
@@ -249,6 +287,7 @@ int obex_folder_listing (FILE* fd, char* name, int flags)
 		"<!DOCTYPE folder-listing SYSTEM \"obex-folder-listing.dtd\">\n");
 	xml_open(fd,0,"folder-listing version=\"1.0\"");
 
+	parent = get_parent_folder_name(name);
 	if (parent) {
 		if (flags & OFL_FLAG_PARENT)
 			xml_print(fd,1,"parent-folder",NULL,0);
